@@ -12,10 +12,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- * MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,6 +26,7 @@
 #include <gtk/gtk.h>
 
 #include <libxfce4util/libxfce4util.h>
+#include <libxfce4ui/libxfce4ui.h>
 #include <xfconf/xfconf.h>
 
 #include "xfce-keyboard-settings.h"
@@ -43,6 +43,18 @@ static GOptionEntry    entries[] = {
 
 
 
+static void
+keyboard_settings_dialog_response (GtkWidget *dialog,
+                                   gint       response_id)
+{
+    if (response_id == GTK_RESPONSE_HELP)
+        xfce_dialog_show_help (GTK_WINDOW (dialog), "xfce4-settings", "keyboard", NULL);
+    else
+        gtk_main_quit ();
+}
+
+
+
 int
 main (int    argc,
       char **argv)
@@ -109,16 +121,16 @@ main (int    argc,
     {
       /* Create and run the settings dialog */
       dialog = xfce_keyboard_settings_create_dialog (settings);
+      gtk_window_set_default_size (GTK_WINDOW (dialog), 450, -1);
 
-      gtk_widget_show (GTK_WIDGET (dialog));
-      g_signal_connect (dialog, "response", G_CALLBACK (gtk_main_quit), NULL);
+      g_signal_connect (dialog, "response",
+          G_CALLBACK (keyboard_settings_dialog_response), NULL);
+      gtk_window_present (GTK_WINDOW (dialog));
 
       /* To prevent the settings dialog to be saved in the session */
       gdk_set_sm_client_id ("FAKE ID");
 
       gtk_main ();
-
-      gtk_widget_destroy (GTK_WIDGET (dialog));
     }
   else
     {
